.. _mixed_gamble_maps:

Mixed gambles statistical maps
==============================

Access
------
See :func:`nilearn.datasets.fetch_mixed_gambles`.

Content
-------
:'zmaps':
:'gain':
:'y':

Notes
-----
zmaps for each subject of the raw dataset dataset available at
https://openneuro.org/datasets/ds000005

See :footcite:t:`Jimura2012`.

References
----------
.. footbibliography::

License
-------
unknown
